@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,19 +37,17 @@ public:
 
     QPixmap gravatarPixmap() const;
 
-private Q_SLOTS:
+private:
     void slotSearchButton();
 
     void slotTextChanged(const QString &text);
     void slotResolvUrlFinish(Gravatar::GravatarResolvUrlJob *job);
-private:
     QPixmap mGravatarPixmap;
-    QLabel *mResultLabel;
-    QLineEdit *mLineEdit;
-    QPushButton *mGetPixmapButton;
-    QCheckBox *mUseLibravatar;
-    QCheckBox *mFallbackGravatar;
-    QCheckBox *mUseHttps;
+    QLabel *mResultLabel = nullptr;
+    QLineEdit *mLineEdit = nullptr;
+    QPushButton *mGetPixmapButton = nullptr;
+    QCheckBox *mUseLibravatar = nullptr;
+    QCheckBox *mFallbackGravatar = nullptr;
 };
 }
 
